function [h,time] = dcc(data)

% Estimate Engle's Dynamic Conditional Correlations model on 
%
% INPUT:  data = (T,N) matrix of individual asset returns
% OUTPUT: h = GARCH(1,1) variance at time T of the minimum variance
%             portfolio, as implied by the estimated DCC variance-covariance matrix
tic
disp(' '), disp('******************************'), disp('Start the DCC model')
[T,N] = size(data);
sigmas = zeros(T,N); stdRes = zeros(T,N);

%*********************************
% Estimate a GARCH for each asset.
for i = 1:N
   y = data(:,i);
   f = GARCH(y);
   eval(['disp(''', 'GARCH estimation terminated for asset ', int2str(i),''')'])
   sigmas(:,i) = f.variance;
   stdRes(:,i) = y./(f.variance.^0.5);
end

%*********************************************************
% Estimate mean reverting dynamic conditional correlations
options = optimset('LargeScale', 'on', 'Display', 'Iter', 'MaxFunEvals', 150, 'MaxIter', 200 , 'TolFun', 0.0001);

x0=[0.2; 0.75]; A=[1 1]; b=1; LB=[0;0]; UB = [1;1];
%x = fminunc('DccLik', x0, options, stdRes);
%x = fminsearch('DccLik', x0, options, stdRes);
x = fmincon('DccLik',x0,A,b,[],[],LB,UB,[],options, stdRes);
   
%***************************************
% Compute the variance-covariance matrix
VarCov=zeros(N,N);
S=corrcoef(stdRes);
Q=cov(stdRes(1:50,:));
eps=stdRes(1,:)';

for t=1:T    
    Q = S*(1-x(1)-x(2)) + x(1)*(eps*eps') + x(2)*Q;
    R = inv(diag(diag(Q))) * Q *  inv(diag(diag(Q)));
    eps=stdRes(t,:)';    
    VarCov = diag(sqrt(sigmas(t,:)))*R*diag(sqrt(sigmas(t,:))); 
end

astar = MinVarPor(VarCov);
Y = data(:,1:N-1)*astar + data(:,N)*(1-astar'*ones(N-1,1)); % (T,1)-vector of portfolio returns
f = GARCH(Y);
h = f.variance(end);
time = toc;