function lik = DccLik(x, stdRes)

% DCC - Estimate the correlation coefficients of the DCC model, using the
% mean reverting specification
if ~isreal(x)
    lik = 1000;
    return
end

[T,N] = size(stdRes);
lik=0;
alpha=x(1); beta=x(2);

S=corrcoef(stdRes);
Q=cov(stdRes(1:50,:));
eps=stdRes(1,:)';

for t = 2:T
   Q = S*(1-alpha-beta) + alpha*(eps*eps') + beta*Q;
   R = inv(diag(diag(Q))) * Q *  inv(diag(diag(Q)));
   eps=stdRes(t,:)';
   lik = lik + 0.5*(log(det(R)) + eps'*inv(R)*eps - eps'*eps);
end
if ~isreal(lik)
    lik = 10e+100;
    return
end