function Figures(path)

% *****************************************************************************************
% *********************** Simone Manganelli - 11 May, 2001  *******************************
% ************************  Last modified - February, 2004  ********************************
% ***********************     European Central Bank      **********************************
% *****************************************************************************************

%
% Codes for the replication of figure and tables of the paper "Asset
% Allocation by Sensitivity Analysis of Volatility"
%
if nargin < 1
    path='j:\Papers\SensitivityGARCH\data\DowStocks.txt';
end

data = dlmread(path,'\t');
warning off

%
% *******************************************************************
% Start the GARCH sensitivity analysis for a portfolio of two stocks.
% *******************************************************************
%
yA=data(:,13); % Column (13) corresponding to General Motors.
yB=data(:,18); % Column (18) corresponding to IBM.

yAB = [yA, yB];
[T,N]=size(data);

WEIGHT = [-1:.1:2]; % Define the vector of weights.
W = size(WEIGHT,2);

variance=zeros(T,W); firstDeriv =zeros(T,W); secondDeriv=zeros(T,W);

for w = 1 : W
    y = WEIGHT(w) * yA + (1-WEIGHT(w)) * yB; % Portfolio returns corresponding to WEIGHT(w).
    
    % Estimate a GARCH (1,1) model for the given time series of portfolio returns.
    f = GARCH(y);
    theta = f.theta;
    variance(:,w) = f.variance; 
    
    % Compute the first and second derivatives.
    [firstDeriv(:,w), secondDeriv(:,w)] = Derivatives([yA,yB], WEIGHT(w), theta, variance(:, w), 1);
    if WEIGHT(w) == 1
        firstDerivA = firstDeriv(:,w); secondDerivA = secondDeriv(:,w);
    elseif WEIGHT(w) == 0
        firstDerivB = firstDeriv(:,w); secondDerivB = secondDeriv(:,w);
    end
        
end

TIME = [1992: (2002-1992)/T :2002]'; TIME = TIME(1:T,:);
MX = max(max([firstDerivA, firstDerivB]));
MN = min(min([firstDerivA, firstDerivB]));
MT = round(max(TIME)); mT = min(TIME);
figure, plot(TIME, firstDerivA, '-', TIME, firstDerivB, ':'), title('First derivative of GM and IBM'), legend('GM','IBM')
figure, plot(TIME, secondDerivA, '-', TIME, mean(secondDeriv')'-secondDerivA, ':')
        title('Second derivative of GM and difference with respect to average'), legend('GM','average-GM')

figure, plot(WEIGHT', variance(T,:)', '-', WEIGHT', firstDeriv(T,:)', ':', WEIGHT', secondDeriv(T,:)','-.')
title('Variance, first and second derivatives at time T'), legend('Variance','First derivative', 'Second derivative')
%emp2D = (firstDeriv(end, 2:end)-firstDeriv(end, 1:end-1))/.01;
%figure, plot([emp2D; secondDeriv(end,2:end)]')