function astar = MinVarPor(VarCov)

% Computes the minimum variance portfolio, for given variance-covariance
% matrix
%
% INPUT: VarCov = (N,N) matrix of variance-covariances
% OUTPUT: astar = (N-1,1) vector of optimal weigths (the last weigth is
% automatically given by 1-sum(astar))

N = length(VarCov);

% Define the partitioned matrix
A = VarCov(1:N-1,1:N-1);
B = VarCov(1:N-1,N);
C = VarCov(N,N);
i = ones(N-1,1);

% Apply the formula for optimal weigths
%astar = inv(A-2*B*i'+C*i*i') * (C*i-B);
astar = inv(A-B*i'-i*B'+C*i*i') * (C*i-B);