function [h,time] = ogarch(data)

% Estimate the Orthogonal GARCH(1,1) model by Alexander (2000)
% 
tic
disp(' '), disp('******************************'), disp('Start the Orthogonal GARCH')
[T,N] = size(data);
%   TAKE PRINCIPAL COMPONENTS OF RISK FACTORS %%%%%%%
sigma = std(data);
X = data*inv(diag(sigma));
[W,L] = eig(X'*X);
m = max(2,N); %m = max(2,sqrt(N));
P = X*W(:,end-m+1:end); % Equation (1) in Alexander (2000)

% Estimate a GARCH for each principal component.
for i = 1:size(P,2)
   y = P(:,i);
   f = GARCH(y);
   eval(['disp(''', 'GARCH estimation terminated for principal component ', int2str(i),''')'])
   sigmaCond(:,i) = f.variance;
   stdRes(:,i) = y./(f.variance.^0.5);
end

% Compute the variance-covariance matrix
for t = 1:T
    A = W(:,end-m+1:end)' * diag(sigma);
    VarCov = A'*diag(sigmaCond(t,:))*A; % Equation (5)
end

astar = MinVarPor(VarCov);
Y = data(:,1:N-1)*astar + data(:,N)*(1-astar'*ones(N-1,1)); % (T,1)-vector of portfolio returns
f = GARCH(Y);
h = f.variance(end);
time = toc;