function TABLE = Table(path)

% *****************************************************************************************
% *********************** Simone Manganelli - 11 May, 2001  *******************************
% ************************  Last modified - February, 2004  ********************************
% ***********************     European Central Bank      **********************************
% *****************************************************************************************

%
% Codes for the replication of the graphs and results of the paper "Sensitivity Analysis of GARCH 
% Models: A New Tool for Risk Management", by Simone Manganelli, Vladimiro Ceci and Walter Vecchiato.
%
if nargin < 1
    path='j:\Papers\SensitivityGARCH\data\DowStocks.txt';
end

data = dlmread(path,'\t');
warning off

%
% *******************************************************************
% Select the five portfolios of table
% *******************************************************************
%
y2=data(:,1:2); % Portfolio with 2 stocks
y5=data(:,1:5); % Portfolio with 5 stocks
y10=data(:,1:10); % Portfolio with 10 stocks
y20=data(:,1:20); % Portfolio with 20 stocks
y30=data(:,1:30); % Portfolio with 30 stocks

index = [2,5,10,20,30];
TABLE = [];

for i = 1:5
    eval(['y = y', int2str(index(i)), ';'])
    
    % Estimate the variance-covariance matrix with different methods and
    % compute the entries of the table
    %
    % 1) Dynamic Conditional Correlation
    [h1,time1] = dcc(y);
    %
    % 2) Orthogonal GARCH
    [h2,time2] = ogarch(y);
    %
    % 3) EWMA
    [h3,time3] = ewma(y);
    %
    % 4) Sensitivity Analysis
    [h4,time4] = SensitivityAnalysis(y);
    
    % Update table
    %
    %TABLE = [TABLE, [[h1, h1-h4, time1];[h2, h2-h4, time2];[h3, h3-h4, time3];[h4, h4-h4, time4]]]
    Vol1 = sqrt(252*h1); Vol2 = sqrt(252*h2); Vol3 = sqrt(252*h3); Vol4 = sqrt(252*h4);
    TABLE = [TABLE, [[Vol1, 100*(Vol1-Vol4)/Vol4, time1];[Vol2, 100*(Vol2-Vol4)/Vol4, time2];[Vol3, 100*(Vol3-Vol4)/Vol4, time3];[Vol4, 0, time4]]]
end